pub fn store(values: [Field], hash: Field)
Stores values represented as slice in execution cache to be later obtained by its hash.
Stores values represented as slice in execution cache to be later obtained by its hash.